@@ -192,6 +192,16 @@ public:
                              double alpha_pr,
                              int ls_trials);
 
+  virtual
+  bool user_callback_full_iterate(hiopVector& x,
+                                  hiopVector& z_L,
+                                  hiopVector& z_U,
+                                  hiopVector& y_c,
+                                  hiopVector& y_d,
+                                  hiopVector& s,
+                                  hiopVector& v_L,
+                                  hiopVector& v_U);
+
   virtual
   bool user_force_update(int iter,
                          double& obj_value,
